﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

namespace ConsoleApp1
{
    class Jira
    {
        const string QUERY_URL_FORMAT = "http://{0}/rest/api/latest/{1}";
        string _baseUrl;
        CookieContainer _cookies;
        HttpClient _httpClient;

        public async Task<bool> Login(string jiraServer, string userId, string password)
        {
            string url = string.Format(QUERY_URL_FORMAT, jiraServer, "myself");
            string authHeader = CreateBasicAuth(userId, password);

            HttpClientHandler handler = new HttpClientHandler();
            _cookies = new CookieContainer();
            handler.CookieContainer = _cookies;

            HttpClient hc = new HttpClient(handler);

            hc.DefaultRequestHeaders.Add("Authorization", authHeader);

            HttpResponseMessage hrm = await hc.GetAsync(url);
            if (hrm.StatusCode == System.Net.HttpStatusCode.Unauthorized)
            {
                return false;
            }

            _baseUrl = string.Format(QUERY_URL_FORMAT, jiraServer, "");
            _httpClient = hc;

            return true;
        }

        private string CreateBasicAuth(string userId, string password)
        {
            string text = userId + ":" + password;
            byte[] buf = Encoding.UTF8.GetBytes(text);
            return "Basic " + Convert.ToBase64String(buf);
        }

        public async Task<SearchResult> GetIssuesByAssignee(string projectKey, string assignee)
        {
            string url = _baseUrl + "search?jql=assignee=" + assignee + " and project=" + projectKey;

            HttpResponseMessage hrm = await _httpClient.GetAsync(url);

            string text = await hrm.Content.ReadAsStringAsync();

            SearchResult result = Newtonsoft.Json.JsonConvert.DeserializeObject<SearchResult>(text);
            return result;
        }
    }
}
